==> cloud-4.0.0-alpha1.tar.gz: cloud/modules/cloud_cluster_worker/src/Plugin/QueueWorker/CloudClusterWorkerSyncResourcesQueueWorker.php <==
<?php

namespace Drupal\cloud_cluster_worker\Plugin\QueueWorker;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use GuzzleHttp\ClientInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Cloud Cluster Worker Sync Resources Queue.
 *
 * @QueueWorker(
 *   id = "cloud_cluster_worker_sync_resources_queue",
 *   title = @Translation("Cloud Cluster Worker Sync Resources Queue"),
 *   cron = {"time" = 60}
 * )
 */
class CloudClusterWorkerSyncResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  const API_PATH = '/cloud_cluster/sync';

  const CLOUD_CONTEXT_UUID_LENGTH = 12;

  use StringTranslationTrait;

  /**
   * A logger instance.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Stores the configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Guzzle Http Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   A logger factory instance.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The http client.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    LoggerChannelFactoryInterface $logger_factory,
    ConfigFactoryInterface $config_factory,
    ClientInterface $http_client
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->logger = $logger_factory->get('cloud_cluster_worker');
    $this->configFactory = $config_factory;
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('logger.factory'),
      $container->get('config.factory'),
      $container->get('http_client')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    $cloud_context = $data['cloud_context'];
    $entity_type = $data['entity_type'];
    $resource_jsons = $data['resource_jsons'];

    $config = $this->configFactory
      ->get('cloud_cluster_worker.settings');

    try {
      $headers = [
        'Authorization' => 'Bearer ' . base64_encode($config->get('cloud_cluster_worker_token')),
        'Content-Type' => 'application/json',
      ];

      $endpoint_url = $config->get('cloud_cluster_worker_api_endpoint');

      // Remove the '/' if the endpoint url ends with '/'.
      if (substr($endpoint_url, -1) === '/') {
        $endpoint_url = substr($endpoint_url, 0, strlen($endpoint_url) - 1);
      }

      $cloud_cluster_worker_name = $config->get('cloud_cluster_worker_id');
      $response = $this->httpClient->post(
        $endpoint_url . self::API_PATH,
        [
          'body' => json_encode([
            'cloud_cluster_worker_name' => $cloud_cluster_worker_name,
            'cloud_context' => $cloud_context . '_' . substr($cloud_cluster_worker_name, -self::CLOUD_CONTEXT_UUID_LENGTH),
            'entity_type' => $entity_type,
            'resource_jsons' => $resource_jsons,
          ]),
          'headers' => $headers,
        ]
      );

      $output = json_decode($response->getBody()->getContents(), TRUE);
      if ($response->getStatusCode() !== 201) {
        $this->logger->error($output['error'] ?? 'Unknown error.');
      }
    }
    catch (\Exception $error) {
      $this->logger->error($error->getMessage());
    }
  }

}

==> cloud-8.0.0-alpha1.tar.gz: cloud/modules/cloud_cluster_worker/src/Plugin/QueueWorker/CloudClusterWorkerSyncResourcesQueueWorker.php <==
<?php

namespace Drupal\cloud_cluster_worker\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\cloud_cluster_worker\Service\CloudClusterWorkerServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Cloud Cluster Worker Sync Resources Queue.
 *
 * @QueueWorker(
 *   id = "cloud_cluster_worker_sync_resources_queue",
 *   title = @Translation("Cloud Cluster Worker Sync Resources Queue"),
 *   cron = {"time" = 60}
 * )
 */
class CloudClusterWorkerSyncResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The resources synchronization service.
   *
   * @var \Drupal\cloud_cluster_worker\Service\CloudClusterWorkerService
   */
  protected $clusterWorker;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\cloud_cluster_worker\Service\CloudClusterWorkerServiceInterface $cluster_worker
   *   The resources synchronization service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    CloudClusterWorkerServiceInterface $cluster_worker,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->clusterWorker = $cluster_worker;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('cloud_cluster_worker')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $this->clusterWorker->sendSyncRequest($data['cloud_context'], $data['entity_type'], $data['resource_jsons']);
  }

}
